==> simgrid_3.9~rc1.orig.tar.gz: SimGrid-3.9/doc/html/group__simix__host__management.js <==
var group__simix__host__management =
[
    [ "smx_host_t", "group__simix__host__management.html#ga5540d4f66a2cbc953bfd0d9917ec22ee", null ],
    [ "simcall_host_get_by_name", "group__simix__host__management.html#ga22bd604a7c15c1980e0ed09281141472", null ],
    [ "simcall_host_get_name", "group__simix__host__management.html#gac627f752c965060cb592ebda7ff5e8ce", null ],
    [ "simcall_host_get_properties", "group__simix__host__management.html#ga03e97c1154f4925d1fb378d68dd5a888", null ],
    [ "simcall_asr_get_properties", "group__simix__host__management.html#ga1a3288b39aba9f321caca13166518cc0", null ],
    [ "simcall_host_get_speed", "group__simix__host__management.html#gaa45133ec4a6376f0de1efb4e08746f2c", null ],
    [ "simcall_host_get_available_speed", "group__simix__host__management.html#gaa93a5302ec2a513b76498b91428fefe2", null ],
    [ "simcall_host_get_state", "group__simix__host__management.html#ga2683ae7336c84958f9fba0c2a8e502fd", null ],
    [ "simcall_host_get_data", "group__simix__host__management.html#ga6acb64cfef3e7284442f6e20bee9317d", null ],
    [ "simcall_host_set_data", "group__simix__host__management.html#ga8201c0350e48d696ef915e4fe668014b", null ],
    [ "simcall_host_execute", "group__simix__host__management.html#ga5257c159ed0002779a0d88a1e067bd20", null ],
    [ "simcall_host_parallel_execute", "group__simix__host__management.html#ga57ef6dbb3d85979561de1881d3cba1bb", null ],
    [ "simcall_host_execution_destroy", "group__simix__host__management.html#gaf31f9cd17e99f88b734b37a91f25d476", null ],
    [ "simcall_host_execution_cancel", "group__simix__host__management.html#gab177e0a327bde207864adbb4abf90e57", null ],
    [ "simcall_host_execution_get_remains", "group__simix__host__management.html#ga23839f5acd57bb8d12620d0e1bad56c1", null ],
    [ "simcall_host_execution_get_state", "group__simix__host__management.html#ga66026abb4f24bd3a528a9bcc41200c4f", null ],
    [ "simcall_host_execution_set_priority", "group__simix__host__management.html#ga3df7d10c87185d6c03c90cfa3b62cc43", null ],
    [ "simcall_host_execution_wait", "group__simix__host__management.html#ga8760a71314f39b57eafca4782251369f", null ]
];

==> simgrid_3.10.orig.tar.gz: SimGrid-3.10/doc/html/group__simix__host__management.js <==
var group__simix__host__management =
[
    [ "smx_host_t", "group__simix__host__management.html#ga5540d4f66a2cbc953bfd0d9917ec22ee", null ],
    [ "simcall_host_get_by_name", "group__simix__host__management.html#ga22bd604a7c15c1980e0ed09281141472", null ],
    [ "simcall_host_get_name", "group__simix__host__management.html#gac627f752c965060cb592ebda7ff5e8ce", null ],
    [ "simcall_host_get_properties", "group__simix__host__management.html#ga03e97c1154f4925d1fb378d68dd5a888", null ],
    [ "simcall_asr_get_properties", "group__simix__host__management.html#ga1a3288b39aba9f321caca13166518cc0", null ],
    [ "simcall_host_get_speed", "group__simix__host__management.html#gaa45133ec4a6376f0de1efb4e08746f2c", null ],
    [ "simcall_host_get_core", "group__simix__host__management.html#gada381d983887aefa0ecfa92395aead7b", null ],
    [ "simcall_host_get_process_list", "group__simix__host__management.html#gaefe3f6813e0791704516253577457058", null ],
    [ "simcall_host_get_available_speed", "group__simix__host__management.html#gaa93a5302ec2a513b76498b91428fefe2", null ],
    [ "simcall_host_get_state", "group__simix__host__management.html#ga2683ae7336c84958f9fba0c2a8e502fd", null ],
    [ "simcall_host_get_data", "group__simix__host__management.html#ga6acb64cfef3e7284442f6e20bee9317d", null ],
    [ "simcall_host_set_data", "group__simix__host__management.html#ga8201c0350e48d696ef915e4fe668014b", null ],
    [ "simcall_host_get_current_power_peak", "group__simix__host__management.html#ga51aacd521d7590712def7fcc86367491", null ],
    [ "simcall_host_get_power_peak_at", "group__simix__host__management.html#ga0656f3e6508c217106c8d760afdcb11d", null ],
    [ "simcall_host_get_nb_pstates", "group__simix__host__management.html#gaaf0a2fb59b6754184673bcc775401da1", null ],
    [ "simcall_host_set_power_peak_at", "group__simix__host__management.html#ga0b9cc33e2ba9c59627be871c46be9892", null ],
    [ "simcall_host_get_consumed_energy", "group__simix__host__management.html#ga15cc5be1060eae3638ac2c00ec5364ef", null ],
    [ "simcall_host_execute", "group__simix__host__management.html#ga5257c159ed0002779a0d88a1e067bd20", null ],
    [ "simcall_host_parallel_execute", "group__simix__host__management.html#ga57ef6dbb3d85979561de1881d3cba1bb", null ],
    [ "simcall_host_execution_destroy", "group__simix__host__management.html#gaf31f9cd17e99f88b734b37a91f25d476", null ],
    [ "simcall_host_execution_cancel", "group__simix__host__management.html#gab177e0a327bde207864adbb4abf90e57", null ],
    [ "simcall_host_execution_get_remains", "group__simix__host__management.html#ga23839f5acd57bb8d12620d0e1bad56c1", null ],
    [ "simcall_host_execution_get_state", "group__simix__host__management.html#ga66026abb4f24bd3a528a9bcc41200c4f", null ],
    [ "simcall_host_execution_set_priority", "group__simix__host__management.html#ga3df7d10c87185d6c03c90cfa3b62cc43", null ],
    [ "simcall_host_execution_wait", "group__simix__host__management.html#ga8760a71314f39b57eafca4782251369f", null ]
];
